more muttng -> madmutt
[apps/madmutt.git] / init.h
diff --git a/init.h b/init.h
index 9580202..65d5e1f 100644 (file)
--- a/init.h
+++ b/init.h
@@ -35,7 +35,7 @@
 #define DT_SYN          9       /* synonym for another variable */
 #define DT_ADDR         10      /* e-mail address */
 #define DT_USER         11      /* user defined via $user_ */
-#define DT_SYS          12      /* pre-defined via $muttng_ */
+#define DT_SYS          12      /* pre-defined via $madmutt_ */
 
 #define DTYPE(x) ((x) & DT_MASK)
 
@@ -81,9 +81,6 @@ struct option_t {
 /* build complete documentation */
 
 #ifdef _MAKEDOC
-# ifndef USE_IMAP
-#  define USE_IMAP
-# endif
 # ifndef MIXMASTER
 #  define MIXMASTER "mixmaster"
 # endif
@@ -149,7 +146,7 @@ struct option_t MuttVars[] = {
    ** check only happens after the \fIfirst\fP edit of the file).  When set
    ** to \fIno\fP, composition will never be aborted.
    */
-  {"alias_file", DT_PATH, R_NONE, UL &AliasFile, "~/.muttngrc"},
+  {"alias_file", DT_PATH, R_NONE, UL &AliasFile, "~/.madmuttrc"},
   /*
    ** .pp
    ** The default file in which to save aliases created by the 
@@ -283,7 +280,7 @@ struct option_t MuttVars[] = {
   {"attach_remind_regexp", DT_RX, R_NONE, UL &AttachRemindRegexp, "attach"},
   /*
    ** .pp
** If this variable is non-empty, muttng will scan a message's contents
    ** before sending for this regular expression. If it is found, it will
    ** ask for what to do depending on the setting of $$abort_noattach.
    ** .pp
@@ -481,7 +478,7 @@ struct option_t MuttVars[] = {
    ** If it is \fIset\fP and Mutt-ng was build with gpgme support, the gpgme code for
    ** S/MIME and PGP will be used instead of the classic code.
    ** .pp
** \fBNote\fP: You need to use this option in your \fT.muttngrc\fP configuration
    ** file as it won't have any effect when used interactively.
    */
 
@@ -528,7 +525,7 @@ struct option_t MuttVars[] = {
    ** \fT-d\fP command line option.
    **
    ** .pp
** Currently, this number must be >= 0 and <= 5 and muttng
    ** must be started with \fT-d\fP to enable debugging at all;
    ** enabling at runtime is not possible.
    */
@@ -589,13 +586,13 @@ struct option_t MuttVars[] = {
    ** filtered message is read from the standard output.
    */
 #if defined(USE_DOTLOCK)
-  {"dotlock_program", DT_PATH, R_NONE, UL &MuttDotlock, "$muttng_bindir/muttng_dotlock"},
+  {"dotlock_program", DT_PATH, R_NONE, UL &MuttDotlock, "$madmutt_bindir/muttng_dotlock"},
   /*
    ** .pp
    ** Availability: Dotlock
    **
    ** .pp
-   ** Contains the path of the \fTmuttng_dotlock(1)\fP binary to be used by
+   ** Contains the path of the \fTmadmutt_dotlock(1)\fP binary to be used by
    ** Mutt-ng.
    */
 #endif
@@ -700,11 +697,6 @@ struct option_t MuttVars[] = {
   ** Manually sets the \fIenvelope\fP sender for outgoing messages.
   ** This value is ignored if ``$$use_envelope_from'' is unset.
   */
-  {"escape", DT_STR, R_NONE, UL &EscChar, "~"},
-  /*
-   ** .pp
-   ** Escape character to use for functions in the builtin editor.
-   */
   {"fast_reply", DT_BOOL, R_NONE, OPTFASTREPLY, "no" },
   /*
    ** .pp
@@ -1009,15 +1001,11 @@ struct option_t MuttVars[] = {
    ** mailing list when this option is set, use the \fIlist-reply\fP
    ** function; \fIgroup-reply\fP will reply to both the sender and the
    ** list.
** Remember: This option works only for mailing lists which are explicitly set in your muttngrc
    ** configuration file.
    */
-#ifdef USE_IMAP
   {"imap_authenticators", DT_STR, R_NONE, UL &ImapAuthenticators, "" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** This is a colon-delimited list of authentication methods Mutt-ng may
    ** attempt to use to log in to an IMAP server, in the order Mutt-ng should
@@ -1042,12 +1030,8 @@ struct option_t MuttVars[] = {
    ** your server on connection, and add them to the set of mailboxes
    ** it polls for new mail. See also the ``$mailboxes'' command.
    */
-  
   {"imap_delim_chars", DT_STR, R_NONE, UL &ImapDelimChars, "/."},
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** This contains the list of characters which you would like to treat
    ** as folder separators for displaying IMAP paths. In particular it
@@ -1055,9 +1039,6 @@ struct option_t MuttVars[] = {
    */
   {"imap_headers", DT_STR, R_INDEX, UL &ImapHeaders, "" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** Mutt-ng requests these header fields in addition to the default headers
    ** (``DATE FROM SUBJECT TO CC MESSAGE-ID REFERENCES CONTENT-TYPE
@@ -1069,9 +1050,6 @@ struct option_t MuttVars[] = {
    */
   {"imap_home_namespace", DT_STR, R_NONE, UL &ImapHomeNamespace, "" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** You normally want to see your personal folders alongside
    ** your \fTINBOX\fP in the IMAP browser. If you see something else, you may set
@@ -1079,9 +1057,6 @@ struct option_t MuttVars[] = {
    */
   {"imap_keepalive", DT_NUM, R_NONE, UL &ImapKeepalive, "900" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** This variable specifies the maximum amount of time in seconds that Mutt-ng
    ** will wait before polling open IMAP connections, to prevent the server
@@ -1097,9 +1072,6 @@ struct option_t MuttVars[] = {
    */
   {"imap_login", DT_STR, R_NONE, UL &ImapLogin, "" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** Your login name on the IMAP server.
    ** .pp
@@ -1107,9 +1079,6 @@ struct option_t MuttVars[] = {
    */
   {"imap_list_subscribed", DT_BOOL, R_NONE, OPTIMAPLSUB, "no" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** This variable configures whether IMAP folder browsing will look for
    ** only subscribed folders or all folders.  This can be toggled in the
@@ -1124,9 +1093,6 @@ struct option_t MuttVars[] = {
    */
   {"imap_pass", DT_STR, R_NONE, UL &ImapPass, "" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** Specifies the password for your IMAP account.  If \fIunset\fP, Mutt-ng will
    ** prompt you for your password when you invoke the fetch-mail function.
@@ -1137,9 +1103,6 @@ struct option_t MuttVars[] = {
    */
   {"imap_passive", DT_BOOL, R_NONE, OPTIMAPPASSIVE, "yes" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** When \fIset\fP, Mutt-ng will not open new IMAP connections to check for new
    ** mail.  Mutt-ng will only check for new mail over existing IMAP
@@ -1149,9 +1112,6 @@ struct option_t MuttVars[] = {
    */
   {"imap_peek", DT_BOOL, R_NONE, OPTIMAPPEEK, "yes" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** If \fIset\fP, Mutt-ng will avoid implicitly marking your mail as read whenever
    ** you fetch a message from the server. This is generally a good thing,
@@ -1160,18 +1120,12 @@ struct option_t MuttVars[] = {
    */
   {"imap_reconnect", DT_QUAD, R_NONE, OPT_IMAPRECONNECT, "ask-yes" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** Controls whether or not Mutt-ng will try to reconnect to IMAP server when
    ** the connection is lost.
    */
   {"imap_servernoise", DT_BOOL, R_NONE, OPTIMAPSERVERNOISE, "yes" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** When \fIset\fP, Mutt-ng will display warning messages from the IMAP
    ** server as error messages. Since these messages are often
@@ -1181,16 +1135,12 @@ struct option_t MuttVars[] = {
    */
   {"imap_user", DT_STR, R_NONE, UL &ImapUser, "" },
   /*
-   ** .pp
-   ** Availability: IMAP
-   **
    ** .pp
    ** The name of the user whose mail you intend to access on the IMAP
    ** server.
    ** .pp
    ** This variable defaults to your user name on the local machine.
    */
-#endif
   {"implicit_autoview", DT_BOOL, R_NONE, OPTIMPLICITAUTOVIEW, "no" },
   /*
    ** .pp
@@ -1463,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** This specifies the folder into which read mail in your ``$$spoolfile''
    ** folder will be appended.
    */
-  {"muttng_version", DT_SYS, R_NONE, 0, VERSION },
+  {"madmutt_version", DT_SYS, R_NONE, 0, VERSION },
   /*
    ** .pp
** \fIThis is a read-only system property and specifies muttng's
    ** version string.\fP
    */
-  {"muttng_revision", DT_SYS, R_NONE, 0, MUTT_REVISION },
+  {"madmutt_revision", DT_SYS, R_NONE, 0, MUTT_REVISION },
   /*
    ** .pp
** \fIThis is a read-only system property and specifies muttng's
    ** subversion revision string.\fP
    */
-  {"muttng_sysconfdir", DT_SYS, R_NONE, 0, SYSCONFDIR },
+  {"madmutt_sysconfdir", DT_SYS, R_NONE, 0, SYSCONFDIR },
   /*
    ** .pp
    ** \fIThis is a read-only system property and specifies the
** directory containing the muttng system-wide configuration.\fP
    */
-  {"muttng_bindir", DT_SYS, R_NONE, 0, BINDIR },
+  {"madmutt_bindir", DT_SYS, R_NONE, 0, BINDIR },
   /*
    ** .pp
    ** \fIThis is a read-only system property and specifies the
** directory containing the muttng binary.\fP
    */
-  {"muttng_docdir", DT_SYS, R_NONE, 0, PKGDOCDIR },
+  {"madmutt_docdir", DT_SYS, R_NONE, 0, PKGDOCDIR },
   /*
    ** .pp
    ** \fIThis is a read-only system property and specifies the
** directory containing the muttng documentation.\fP
    */
 #ifdef USE_HCACHE
 #if HAVE_QDBM
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "qdbm" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "qdbm" },
 #elif HAVE_GDBM
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "gdbm" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "gdbm" },
 #elif HAVE_DB4
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "db4" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "db4" },
 #else
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "unknown" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "unknown" },
 #endif
   /*
    ** .pp
@@ -1509,14 +1459,14 @@ struct option_t MuttVars[] = {
    ** header chaching's database backend.\fP
    */
 #endif
-  {"muttng_folder_path", DT_SYS, R_NONE, 0, "" },
+  {"madmutt_folder_path", DT_SYS, R_NONE, 0, "" },
   /*
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
    ** specifies the full path or URI of the folder currently
    ** open (if any).\fP
    */
-  {"muttng_folder_name", DT_SYS, R_NONE, 0, "" },
+  {"madmutt_folder_name", DT_SYS, R_NONE, 0, "" },
   /*
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
@@ -1526,7 +1476,7 @@ struct option_t MuttVars[] = {
    ** For detection, $$$folder is first taken into account
    ** and simply stripped to form the result when a match is found. For
    ** example, with $$$folder being \fTimap://host\fP and the folder is
** \fTimap://host/INBOX/foo\fP, $$$muttng_folder_name will be just
    ** \fTINBOX/foo\fP.)
    ** .pp
    ** Second, if the initial portion of a name is not $$$folder,
@@ -1535,11 +1485,11 @@ struct option_t MuttVars[] = {
    ** Third and last, the result will be just the name if neither
    ** $$$folder nor a ``/'' were found in the name.
    */
-  {"muttng_pwd", DT_SYS, R_NONE, 0, "" },
+  {"madmutt_pwd", DT_SYS, R_NONE, 0, "" },
   /*
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
** specifies the current working directory of the muttng
    ** binary.\fP
    */
   {"operating_system", DT_STR, R_NONE, UL &OperatingSystem, "" },
@@ -1808,7 +1758,7 @@ struct option_t MuttVars[] = {
    ** deeper threads to fit on the screen.
    */
 #ifdef USE_NNTP
-  {"nntp_cache_dir", DT_PATH, R_NONE, UL &NewsCacheDir, "~/.muttng"},
+  {"nntp_cache_dir", DT_PATH, R_NONE, UL &NewsCacheDir, "~/.madmutt"},
   /*
    ** .pp
    ** Availability: NNTP
@@ -2642,7 +2592,7 @@ struct option_t MuttVars[] = {
    ** certificate that is signed with one of these CA certificates are 
    ** also automatically accepted.
    ** .pp
-   ** Example: \fTset certificate_file=~/.muttng/certificates\fP
+   ** Example: \fTset certificate_file=~/.madmutt/certificates\fP
    */
 # if defined(_MAKEDOC) || !defined (USE_GNUTLS)
   {"ssl_usesystemcerts", DT_BOOL, R_NONE, OPTSSLSYSTEMCERTS, "yes" },
@@ -3560,7 +3510,7 @@ struct option_t MuttVars[] = {
    ** .pp
    ** When \fIunset\fP, Mutt-ng won't stop when the user presses the terminal's
    ** \fIsusp\fP key, usually \fTCTRL+Z\fP. This is useful if you run Mutt-ng
** inside an xterm using a command like ``\fTxterm -e muttng\fP.''
    */
   {"text_flowed", DT_BOOL, R_NONE, OPTTEXTFLOWED, "no" },
   /*
@@ -3707,12 +3657,6 @@ struct option_t MuttVars[] = {
    ** messages, indicating which version of Mutt-ng was used for composing
    ** them.
    */
-  {"visual", DT_PATH, R_NONE, UL &Visual, "" },
-  /*
-   ** .pp
-   ** Specifies the visual editor to invoke when the \fI~v\fP command is
-   ** given in the builtin editor.
-   */
   {"wait_key", DT_BOOL, R_NONE, OPTWAITKEY, "yes" },
   /*
    ** .pp
@@ -3832,9 +3776,6 @@ static const char* Features[] = {
 #ifdef USE_NNTP
   "nntp",
 #endif
-#ifdef USE_IMAP
-  "imap",
-#endif
 #ifdef USE_SSL
   "ssl",
 #endif
@@ -283,7 +280,7 @@ struct option_t MuttVars[] = {
   /*
    ** .pp
-   ** If this variable is non-empty, muttng will scan a message's contents
+   ** If this variable is non-empty, madmutt will scan a message's contents
    ** before sending for this regular expression. If it is found, it will
    ** ask for what to do depending on the setting of $$abort_noattach.
@@ -481,7 +478,7 @@ struct option_t MuttVars[] = {
    ** S/MIME and PGP will be used instead of the classic code.
    ** .pp
-   ** \fBNote\fP: You need to use this option in your \fT.muttngrc\fP configuration
+   ** \fBNote\fP: You need to use this option in your \fT.madmuttrc\fP configuration
    ** file as it won't have any effect when used interactively.
    */
@@ -528,7 +525,7 @@ struct option_t MuttVars[] = {
    **
    ** .pp
-   ** Currently, this number must be >= 0 and <= 5 and muttng
+   ** Currently, this number must be >= 0 and <= 5 and madmutt
    ** must be started with \fT-d\fP to enable debugging at all;
    ** enabling at runtime is not possible.
@@ -1009,15 +1001,11 @@ struct option_t MuttVars[] = {
    ** function; \fIgroup-reply\fP will reply to both the sender and the
    ** list.
-   ** Remember: This option works only for mailing lists which are explicitly set in your muttngrc
+   ** Remember: This option works only for mailing lists which are explicitly set in your madmuttrc
    ** configuration file.
    */
@@ -1463,45 +1413,45 @@ struct option_t MuttVars[] = {
   /*
    ** .pp
-   ** \fIThis is a read-only system property and specifies muttng's
+   ** \fIThis is a read-only system property and specifies madmutt's
    ** version string.\fP
    */
@@ -1463,45 +1413,45 @@ struct option_t MuttVars[] = {
   /*
    ** .pp
-   ** \fIThis is a read-only system property and specifies muttng's
+   ** \fIThis is a read-only system property and specifies madmutt's
    ** subversion revision string.\fP
    */
@@ -1463,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and specifies the
-   ** directory containing the muttng system-wide configuration.\fP
+   ** directory containing the madmutt system-wide configuration.\fP
    */
@@ -1463,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and specifies the
-   ** directory containing the muttng binary.\fP
+   ** directory containing the madmutt binary.\fP
    */
@@ -1463,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and specifies the
-   ** directory containing the muttng documentation.\fP
+   ** directory containing the madmutt documentation.\fP
    */
 #ifdef USE_HCACHE
@@ -1526,7 +1476,7 @@ struct option_t MuttVars[] = {
    ** and simply stripped to form the result when a match is found. For
    ** example, with $$$folder being \fTimap://host\fP and the folder is
-   ** \fTimap://host/INBOX/foo\fP, $$$muttng_folder_name will be just
+   ** \fTimap://host/INBOX/foo\fP, $$$madmutt_folder_name will be just
    ** \fTINBOX/foo\fP.)
    ** .pp
@@ -1535,11 +1485,11 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
-   ** specifies the current working directory of the muttng
+   ** specifies the current working directory of the madmutt
    ** binary.\fP
    */
@@ -3560,7 +3510,7 @@ struct option_t MuttVars[] = {
    ** When \fIunset\fP, Mutt-ng won't stop when the user presses the terminal's
    ** \fIsusp\fP key, usually \fTCTRL+Z\fP. This is useful if you run Mutt-ng
-   ** inside an xterm using a command like ``\fTxterm -e muttng\fP.''
+   ** inside an xterm using a command like ``\fTxterm -e madmutt\fP.''
    */
   {"text_flowed", DT_BOOL, R_NONE, OPTTEXTFLOWED, "no" },